bde_catalog_load: Load BdE catalog metadata

View source: R/catalogs.R

bde_catalog_loadR Documentation

Load BdE catalog metadata

Description

Load BdE time series catalog metadata.

Usage

bde_catalog_load(
  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
  parse_dates = TRUE,
  cache_dir = NULL,
  update_cache = FALSE,
  verbose = FALSE
)

Arguments

catalog

A single catalog identifier to load, or "ALL" to load every catalog. See Details.

parse_dates

Logical. If TRUE, date columns are parsed with bde_parse_dates().

cache_dir

A path to a cache directory. The directory can also be set with options using options(bde_cache_dir = "path/to/dir").

update_cache

Logical. If TRUE, the requested file is refreshed in cache_dir.

verbose

Logical. If TRUE, display information useful for debugging.

Details

Accepted values for catalog are:

CODE PUBLICATION UPDATE FREQUENCY FREQUENCY
"BE" Statistical Bulletin Daily Monthly
"SI" Summary Indicators Daily Daily
"TC" Exchange Rates Daily Daily
"TI" Interest Rates Daily Daily
"PB" Bank Lending Survey Quarterly Quarterly

Use "ALL" as a shorthand for loading all catalogs at once.

If the requested catalog is not cached, this function calls bde_catalog_update().

Value

A tibble with the requested catalog metadata.

time series bulk data download.

See Also

Other catalog: bde_catalog_search(), bde_catalog_update()

Examples



bde_catalog_load("TI", verbose = TRUE)



tidyBdE documentation built on May 21, 2026, 5:07 p.m.