bde_catalog_update: Update BdE catalog files

View source: R/catalogs.R

bde_catalog_updateR Documentation

Update BdE catalog files

Description

Update BdE time series catalog files.

Usage

bde_catalog_update(
  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

catalog

A single catalog identifier to update, or "ALL" to update every catalog. See Details.

cache_dir

A path to a cache directory. The directory can also be set with options using options(bde_cache_dir = "path/to/dir").

verbose

Logical. If TRUE, display information useful for debugging.

Details

Accepted values for catalog are:

CODE PUBLICATION UPDATE FREQUENCY FREQUENCY
"BE" Statistical Bulletin Daily Monthly
"SI" Summary Indicators Daily Daily
"TC" Exchange Rates Daily Daily
"TI" Interest Rates Daily Daily
"PB" Bank Lending Survey Quarterly Quarterly

Use "ALL" as a shorthand for updating all catalogs at once.

Value

An invisible list of download results.

time series bulk data download.

See Also

Other catalog: bde_catalog_load(), bde_catalog_search()

Examples



bde_catalog_update("TI", verbose = TRUE)



tidyBdE documentation built on May 21, 2026, 5:07 p.m.