bde_indicators: Selected Spanish macroeconomic indicators

bde_indicatorsR Documentation

Selected Spanish macroeconomic indicators

Description

Retrieve selected Spanish macroeconomic indicators. Metadata is available in bde_ind_db.

Usage

bde_ind_gdp_var(series_label = "GDP_YoY", ...)

bde_ind_unemployment_rate(series_label = "Unemployment_Rate", ...)

bde_ind_euribor_12m_monthly(series_label = "Euribor_12M_Monthly", ...)

bde_ind_euribor_12m_daily(series_label = "Euribor_12M_Daily", ...)

bde_ind_cpi_var(series_label = "Consumer_price_index_YoY", ...)

bde_ind_ibex_monthly(series_label = "IBEX_index_month", ...)

bde_ind_ibex_daily(series_label = "IBEX_index_day", ...)

bde_ind_gdp_quarterly(series_label = "GDP_quarterly_value", ...)

bde_ind_population(series_label = "Population_Spain", ...)

Arguments

series_label

An optional character vector of labels to assign to the extracted series.

...

Arguments passed on to bde_series

out_format

The output format, either "wide" or "long". See Value for details and the Examples section.

parse_numeric

Logical. If TRUE, parse observation columns as double vectors. See Note.

extract_metadata

Logical. If TRUE, return the metadata associated with the requested series.

parse_dates

Logical. If TRUE, date columns are parsed with bde_parse_dates().

update_cache

Logical. If TRUE, the requested file is refreshed in cache_dir.

cache_dir

Path to a cache directory. The directory can also be set with options(bde_cache_dir = "path/to/dir").

verbose

Logical. If TRUE, display informative messages.

Details

These functions are convenient wrappers for bde_series_load() that retrieve specific series. Use ⁠verbose = TRUE, extract_metadata = TRUE⁠ to inspect the metadata and source.

Value

A tibble with the requested indicator series.

Note

These functions attempt to parse columns as double values. For some time series, a warning may be displayed if parsing fails. Set parse_numeric = FALSE to disable numeric parsing.

Banco de España time series bulk data download.

See Also

bde_series_load() for loading arbitrary bulk CSV series and bde_catalog_search() for finding series in catalog metadata.

Selected indicators and metadata: bde_ind_db

Examples



bde_ind_gdp_var()



tidyBdE documentation built on July 7, 2026, 1:06 a.m.