tidyBdE-package: tidyBdE: Retrieve Time Series Data from 'Banco de España'

tidyBdE-packageR Documentation

tidyBdE: Retrieve Time Series Data from 'Banco de España'

Description

logo

Tools for retrieving 'Banco de España' ('BdE') time series data as 'tibble' objects from bulk CSV files and the 'Statistics web service (API)'. Bulk CSV functions use stable 'BdE' sequential numbers, while API functions use API series codes. Catalog functions support discovery and local caching. Plotting helpers provide 'ggplot2' palettes, scales and themes. 'Banco de España' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system alongside the European Central Bank. This package is not sponsored, endorsed or administered by 'Banco de España'.

Author(s)

Maintainer: Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

  • Banco de España (ROR) (Data copyright holder) [copyright holder]

See Also

Useful links:


tidyBdE documentation built on July 7, 2026, 1:06 a.m.