Learn R Programming

tidyBdE (version 0.2.4)

bde_catalog_load: Load BdE catalogs

Description

Load the time-series catalogs provided by BdE.

Usage

bde_catalog_load(
  catalog = "ALL",
  parse_dates = TRUE,
  cache_dir = NULL,
  update_cache = FALSE,
  verbose = FALSE
)

Arguments

catalog

A single value indicating the catalogs to be updated or "ALL" as a shorthand. See Details.

parse_dates

Logical. If TRUE the dates would be parsed using bde_parse_dates().

cache_dir

A path to a cache directory. The directory can also be set via options with options(bde_cache_dir = "path/to/dir").

update_cache

Logical. If TRUE the requested file would be updated on the cache_dir.

verbose

Logical TRUE or FALSE, display information useful for debugging.

Value

A tibble

Details

Accepted values for catalog are:

CODE PUBLICATION UPDATE FREQUENCY FREQUENCY
BE Statistical Bulletin Daily Monthly
SI Summary Indicators Daily Daily
TC Exchange Rates Daily Daily
TI Interest Rates Daily Daily
PB Bank Lending Survey Quarterly Quarterly

Use "ALL" as a shorthand for updating all the catalogs at a glance.

If the requested catalog is not cached bde_catalog_update() is invoked.

See Also

Other catalog: bde_catalog_search(), bde_catalog_update()

Examples

Run this code
# NOT RUN {
bde_catalog_load("TI", verbose = TRUE)
# }

Run the code above in your browser using DataLab