powered by
Load the time-series catalogs provided by BdE.
bde_catalog_load( catalog = "ALL", parse_dates = TRUE, cache_dir = NULL, update_cache = FALSE, verbose = FALSE )
A single value indicating the catalogs to be updated or "ALL" as a shorthand. See Details.
"ALL"
Logical. If TRUE the dates would be parsed using bde_parse_dates().
TRUE
bde_parse_dates()
A path to a cache directory. The directory can also be set via options with options(bde_cache_dir = "path/to/dir").
options(bde_cache_dir = "path/to/dir")
Logical. If TRUE the requested file would be updated on the cache_dir.
cache_dir
Logical TRUE or FALSE, display information useful for debugging.
FALSE
A tibble
Accepted values for catalog are:
catalog
Use "ALL" as a shorthand for updating all the catalogs at a glance.
If the requested catalog is not cached bde_catalog_update() is invoked.
bde_catalog_update()
Other catalog: bde_catalog_search(), bde_catalog_update()
bde_catalog_search()
# NOT RUN { bde_catalog_load("TI", verbose = TRUE) # }
Run the code above in your browser using DataLab