Learn R Programming

tidyBdE (version 0.2.4)

bde_catalog_update: Update BdE catalogs

Description

Update the time-series catalogs provided by BdE.

Usage

bde_catalog_update(catalog = "ALL", cache_dir = NULL, verbose = FALSE)

Arguments

catalog

A vector of characters indicating the catalogs to be updated or "ALL" as a shorthand. See Details.

cache_dir

A path to a cache directory. The directory can also be set via options with options(bde_cache_dir = "path/to/dir").

verbose

Logical TRUE or FALSE, display information useful for debugging.

Value

None Downloads the catalog file(s) to the local machine.

Details

Accepted values for catalog are:

CODE PUBLICATION UPDATE FREQUENCY FREQUENCY
BE Statistical Bulletin Daily Monthly
SI Summary Indicators Daily Daily
TC Exchange Rates Daily Daily
TI Interest Rates Daily Daily
PB Bank Lending Survey Quarterly Quarterly

Use "ALL" as a shorthand for updating all the catalogs at a glance.

See Also

Other catalog: bde_catalog_load(), bde_catalog_search()

Examples

Run this code
# NOT RUN {
bde_catalog_update("TI", verbose = TRUE)
# }

Run the code above in your browser using DataLab