powered by
Update the time-series catalogs provided by BdE.
bde_catalog_update(catalog = "ALL", cache_dir = NULL, verbose = FALSE)
A vector of characters indicating the catalogs to be updated or "ALL" as a shorthand. See Details.
"ALL"
A path to a cache directory. The directory can also be set via options with options(bde_cache_dir = "path/to/dir").
options(bde_cache_dir = "path/to/dir")
Logical TRUE or FALSE, display information useful for debugging.
TRUE
FALSE
None Downloads the catalog file(s) to the local machine.
Accepted values for catalog are:
catalog
Use "ALL" as a shorthand for updating all the catalogs at a glance.
Other catalog: bde_catalog_load(), bde_catalog_search()
bde_catalog_load()
bde_catalog_search()
# NOT RUN { bde_catalog_update("TI", verbose = TRUE) # }
Run the code above in your browser using DataLab