bde_catalogs: Load, update and search BdE catalog metadata

bde_catalogsR Documentation

Load, update and search BdE catalog metadata

Description

These functions manage BdE time series catalog metadata from the bulk CSV files published by Banco de España.

bde_catalog_load() loads time series catalog metadata into a tibble, bde_catalog_update() refreshes the cached catalog files and bde_catalog_search() searches catalog metadata for keywords.

Usage

bde_catalog_load(
  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
  parse_dates = TRUE,
  cache_dir = NULL,
  update_cache = FALSE,
  verbose = FALSE
)

bde_catalog_update(
  catalog = c("ALL", "BE", "SI", "TC", "TI", "PB"),
  cache_dir = NULL,
  verbose = FALSE
)

bde_catalog_search(pattern, ...)

Arguments

catalog

A catalog identifier or "ALL" to load or update every catalog. See Details.

parse_dates

Logical. If TRUE, date columns are parsed with bde_parse_dates().

cache_dir

Path to a cache directory. The directory can also be set with options(bde_cache_dir = "path/to/dir").

update_cache

Logical. If TRUE, the requested file is refreshed in cache_dir.

verbose

Logical. If TRUE, display informative messages.

pattern

Regular expression to search for. See Details and Examples.

...

Additional arguments passed by bde_catalog_search() to bde_catalog_load().

Details

Accepted values for catalog are:

CODE PUBLICATION UPDATE FREQUENCY FREQUENCY
"BE" Statistical Bulletin Daily Monthly
"SI" Summary Indicators Daily Daily
"TC" Exchange Rates Daily Daily
"TI" Interest Rates Daily Daily
"PB" Bank Lending Survey Quarterly Quarterly

Use "ALL" as a shorthand for loading or updating all catalogs at once.

If the requested catalog is not cached, bde_catalog_load() calls bde_catalog_update().

Note: BdE catalog metadata is currently available in Spanish only. Therefore, search terms passed to bde_catalog_search() must be in Spanish to retrieve results.

bde_catalog_search() uses base::grep() to find matches in the catalog metadata. You can pass regular expressions to broaden the search.

Value

bde_catalog_load() returns a tibble with the requested time series catalog metadata. See vignette("csv_manual", package = "tidyBdE") for details.

bde_catalog_update() returns an invisible list of download results.

bde_catalog_search() returns a tibble with matching catalog rows.

Banco de España time series bulk data download.

See Also

  • bde_series_load() and bde_series_full_load() load bulk CSV series.

  • bde_series_api_load() and bde_series_api_latest() retrieve series through the Statistics web service (API).

Examples



bde_catalog_load("TI", verbose = TRUE)

# Simple search. Search terms must be in Spanish.
# PIB [es] == GDP [en].
bde_catalog_search("PIB")

# Search with a single complex condition.
bde_catalog_search("Francia(.*)PIB")

# Search with multiple complex conditions.
bde_catalog_search("Francia(.*)PIB|Italia(.*)PIB|Alemania(.*)PIB")

bde_catalog_update("TI", verbose = TRUE)



tidyBdE documentation built on July 7, 2026, 1:06 a.m.