| bde_indicators | R Documentation |
Retrieve selected Spanish macroeconomic indicators. Metadata is available in bde_ind_db.
bde_ind_gdp_var(series_label = "GDP_YoY", ...)
bde_ind_unemployment_rate(series_label = "Unemployment_Rate", ...)
bde_ind_euribor_12m_monthly(series_label = "Euribor_12M_Monthly", ...)
bde_ind_euribor_12m_daily(series_label = "Euribor_12M_Daily", ...)
bde_ind_cpi_var(series_label = "Consumer_price_index_YoY", ...)
bde_ind_ibex_monthly(series_label = "IBEX_index_month", ...)
bde_ind_ibex_daily(series_label = "IBEX_index_day", ...)
bde_ind_gdp_quarterly(series_label = "GDP_quarterly_value", ...)
bde_ind_population(series_label = "Population_Spain", ...)
series_label |
An optional character vector of labels to assign to the extracted series. |
... |
Arguments passed on to
|
These functions are convenient wrappers for bde_series_load() that
retrieve specific series. Use verbose = TRUE, extract_metadata = TRUE to
inspect the metadata and source.
A tibble with the requested indicator series.
These functions attempt to parse columns as double values. For some time
series, a warning may be displayed if parsing fails. Set
parse_numeric = FALSE to disable numeric parsing.
Banco de España time series bulk data download.
bde_series_load() for loading arbitrary bulk CSV series and
bde_catalog_search() for finding series in catalog metadata.
Selected indicators and metadata:
bde_ind_db
bde_ind_gdp_var()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.