bde_indicators: Selected Spanish macroeconomic indicators

bde_indicatorsR Documentation

Selected Spanish macroeconomic indicators

Description

Convenience functions for downloading selected Spanish macroeconomic indicators. Metadata is available in bde_ind_db.

Usage

bde_ind_gdp_var(series_label = "GDP_YoY", ...)

bde_ind_unemployment_rate(series_label = "Unemployment_Rate", ...)

bde_ind_euribor_12m_monthly(series_label = "Euribor_12M_Monthly", ...)

bde_ind_euribor_12m_daily(series_label = "Euribor_12M_Daily", ...)

bde_ind_cpi_var(series_label = "Consumer_price_index_YoY", ...)

bde_ind_ibex_monthly(series_label = "IBEX_index_month", ...)

bde_ind_ibex_daily(series_label = "IBEX_index_day", ...)

bde_ind_gdp_quarterly(series_label = "GDP_quarterly_value", ...)

bde_ind_population(series_label = "Population_Spain", ...)

Arguments

series_label

Optional character string or vector of labels to assign to the extracted series.

...

Arguments passed on to bde_series_load

out_format

The format to return, either "wide" or "long". See Value for details and the Examples section.

parse_numeric

Logical. If TRUE, the columns are parsed to double (numeric) values. See Note.

extract_metadata

Logical. If TRUE, the output is the metadata of the requested series.

parse_dates

Logical. If TRUE, date columns are parsed with bde_parse_dates().

update_cache

Logical. If TRUE, the requested file is refreshed in cache_dir.

cache_dir

A path to a cache directory. The directory can also be set with options using options(bde_cache_dir = "path/to/dir").

verbose

Logical. If TRUE, display information useful for debugging.

Details

These functions are convenient wrappers around bde_series_load() for specific series. Use ⁠verbose = TRUE, extract_metadata = TRUE⁠ to inspect the metadata and source.

Value

A tibble with the required series.

See Also

bde_series_load(), bde_catalog_search()

Other indicators: bde_ind_db

Examples



bde_ind_gdp_var()



tidyBdE documentation built on May 21, 2026, 5:07 p.m.