Retrieve selected Spanish macroeconomic indicators. Metadata is available in bde_ind_db.
Usage
bde_ind_gdp_var(series_label = "GDP_YoY", ...)
bde_ind_unemployment_rate(series_label = "Unemployment_Rate", ...)
bde_ind_euribor_12m_monthly(series_label = "Euribor_12M_Monthly", ...)
bde_ind_euribor_12m_daily(series_label = "Euribor_12M_Daily", ...)
bde_ind_cpi_var(series_label = "Consumer_price_index_YoY", ...)
bde_ind_ibex_monthly(series_label = "IBEX_index_month", ...)
bde_ind_ibex_daily(series_label = "IBEX_index_day", ...)
bde_ind_gdp_quarterly(series_label = "GDP_quarterly_value", ...)
bde_ind_population(series_label = "Population_Spain", ...)Arguments
- series_label
Optional character string or vector of labels to assign to the extracted series.
- ...
Arguments passed on to
bde_seriesout_formatOutput format, either
"wide"or"long". See Value for details and the Examples section.parse_numericLogical. If
TRUE, parse columns as double values. See Note.extract_metadataLogical. If
TRUE, return metadata for the requested series.parse_datesLogical. If
TRUE, date columns are parsed withbde_parse_dates().update_cacheLogical. If
TRUE, the requested file is refreshed incache_dir.cache_dirPath to a cache directory. The directory can also be set with
options(bde_cache_dir = "path/to/dir").verboseLogical. If
TRUE, display information useful for debugging.
Value
A tibble with the requested indicator series.
Details
These functions are convenient wrappers for bde_series_load() that
retrieve specific series. Use verbose = TRUE, extract_metadata = TRUE to
inspect the metadata and source.
Note
These functions attempt to parse columns as double values. For some time
series, a warning may be displayed if parsing fails. Set
parse_numeric = FALSE to disable numeric parsing.
See also
bde_series_load() for loading arbitrary bulk CSV series and
bde_catalog_search() for finding series in catalog metadata.
Selected indicators and metadata:
bde_ind_db
Examples
# \donttest{
bde_ind_gdp_var()
#> # A tibble: 121 × 2
#> Date GDP_YoY
#> <date> <dbl>
#> 1 1996-03-01 2.46
#> 2 1996-06-01 2.49
#> 3 1996-09-01 2.87
#> 4 1996-12-01 2.61
#> 5 1997-03-01 3.04
#> 6 1997-06-01 3.26
#> 7 1997-09-01 3.55
#> 8 1997-12-01 4.49
#> 9 1998-03-01 4.33
#> 10 1998-06-01 4.53
#> # ℹ 111 more rows
# }