About BdE file naming
The series name is a positional code showing the location of the table. For
example, table be_6_1 represents the Table 1, Chapter 6 of the
Statistical Bulletin ("BE"). Although it is a unique value, it is subject
to change (i.e. a new table is inserted before).
For that reason, the function bde_series_load() is more suitable for
extracting specific time-series.