| bde_series_load | R Documentation |
The series alias is a positional code showing the location (column and/or row) of the series in the table. Although it is unique, it is not stable enough to use as the series ID because it may change when the series moves.
To ensure series can still be identified after these changes, they are
assigned a sequential number, referred to as series_code in this function.
Note that a single series may appear in different tables, so it can have
several aliases. If you need to search by alias, use
bde_series_full_load().
bde_series_load(
series_code,
series_label = NULL,
out_format = "wide",
parse_dates = TRUE,
parse_numeric = TRUE,
cache_dir = NULL,
update_cache = FALSE,
verbose = FALSE,
extract_metadata = FALSE
)
series_code |
A numeric value, or one coercible with
|
series_label |
Optional character string or vector of labels to assign to the extracted series. |
out_format |
The format to return, either |
parse_dates |
Logical. If |
parse_numeric |
Logical. If |
cache_dir |
A path to a cache directory. The directory can also be set
with options using |
update_cache |
Logical. If |
verbose |
Logical. If |
extract_metadata |
Logical. If |
Load a single BdE time series.
A tibble with a Date column:
With out_format = "wide", each series is presented in a separate column
with the name defined by series_label.
With out_format = "long", the tibble has two additional columns:
serie_name, with the label of each series, and serie_value, with the
corresponding value.
"wide" format is more suitable for exporting to a .csv file, while
"long" format is more suitable for creating plots using
ggplot2::ggplot(). See also tidyr::pivot_longer() and
tidyr::pivot_wider().
This function attempts to coerce the columns to numbers. For some series, a warning may be displayed if the parsing fails.
bde_catalog_load(),
bde_catalog_search(), bde_indicators()
Other series:
bde_series_full_load()
# Show metadata.
bde_series_load(573234, verbose = TRUE, extract_metadata = TRUE)
# Load data.
bde_series_load(573234, extract_metadata = FALSE)
# Load multiple series.
bde_series_load(c(573234, 573214),
series_label = c("US/EUR", "GBP/EUR"),
extract_metadata = TRUE
)
wide <- bde_series_load(c(573234, 573214),
series_label = c("US/EUR", "GBP/EUR")
)
# Show wide output.
wide
# Show long output.
long <- bde_series_load(c(573234, 573214),
series_label = c("US/EUR", "GBP/EUR"),
out_format = "long"
)
long
# Use with `ggplot2`.
library(ggplot2)
ggplot(long, aes(Date, serie_value)) +
geom_line(aes(group = serie_name, color = serie_name)) +
scale_color_bde_d() +
theme_tidybde()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.