| tidyBdE-package | R Documentation |
Tools for retrieving 'Banco de España' ('BdE') time series data as 'tibble' objects from bulk CSV files and the 'Statistics web service (API)'. Bulk CSV functions use stable 'BdE' sequential numbers, while API functions use API series codes. Catalog functions support discovery and local caching. Plotting helpers provide 'ggplot2' palettes, scales and themes. 'Banco de España' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system alongside the European Central Bank. This package is not sponsored, endorsed or administered by 'Banco de España'.
Maintainer: Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]
Authors:
Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]
Other contributors:
Banco de España (ROR) (Data copyright holder) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.