tidyBdE-package: tidyBdE: Retrieve Data from 'Banco de España'

tidyBdE-packageR Documentation

tidyBdE: Retrieve Data from 'Banco de España'

Description

logo

Tools for retrieving time series data from 'Banco de España' ('BdE') as 'tibble' objects. 'Banco de España' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system alongside the European Central Bank. This package is not sponsored, endorsed or administered by 'Banco de España'.

Author(s)

Maintainer: Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


tidyBdE documentation built on May 21, 2026, 5:07 p.m.