tidyBdE: Retrieve Time Series Data from 'Banco de España'
Source:R/tidyBdE-package.R
tidyBdE-package.RdTools for retrieving 'Banco de España' ('BdE') time series data as 'tibble' objects from bulk CSV files and the 'Statistics web service (API)'. Bulk CSV helpers use stable 'BdE' sequential numbers, and API helpers use API series codes. 'Banco de España' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system alongside the European Central Bank. This package is not sponsored, endorsed or administered by 'Banco de España'.
Author
Maintainer: Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]
Authors:
Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]
Other contributors:
Banco de España (ROR) (Data copyright holder) [copyright holder]