tidyBdE: Retrieve Time Series Data from 'Banco de España'
Source:R/tidyBdE-package.R
tidyBdE-package.RdTools for retrieving time series data from 'Banco de España' ('BdE') as 'tibble' objects. 'Banco de España' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system alongside the European Central Bank. This package is not sponsored, endorsed or administered by 'Banco de España'.
Author
Maintainer: Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]
Authors:
Diego H. Herrero dev.dieghernan@gmail.com (ORCID) [copyright holder]