Learn R Programming

tidyBdE (version 0.2.4)

tidyBdE-package: tidyBdE: Download Data from Bank of Spain

Description

logo

Tools to download data series from 'Banco de Espa<U+00F1>a' ('BdE') on 'tibble' format. 'Banco de Espa<U+00F1>a' is the national central bank and, within the framework of the Single Supervisory Mechanism ('SSM'), the supervisor of the Spanish banking system along with the European Central Bank. This package is in no way sponsored endorsed or administered by 'Banco de Espa<U+00F1>a'.

Arguments

See Also

Useful links: